@@ -1,3 +1,4 @@
+/* $Id: renice.h,v 1.3 2000/02/20 21:45:36 bergo Exp $ */
 
 #ifndef GPS_RENICE_H
 
@@ -12,6 +13,9 @@
 #define ERR_NICE_WEIRD2   "Undocumented error.\n"\
                           "Blame Linus and the BSD guys."
 
+#define ERR_CANT_GET_NICE "Unable to stat current nice value,\n"\
+                          "thus cannot change it either."
+
 void renice_dialog(GtkWidget * widget, gpointer data);
 void renice_set_cancel(GtkWidget *gw,gpointer data);
 void renice_set_ok(GtkWidget *gw,gpointer data);
